@@ -130,7 +130,7 @@ Proceeding by copying instead of symlinking."
         &desired_symlinks,
         &desired_templates,
         &mut cache,
-        &opt,
+        opt,
     );
 
     // === Post-deploy ===
@@ -286,7 +286,7 @@ fn run_deploy<A: ActionRunner>(
         existing_symlinks.difference(&desired_symlinks.keys().cloned().collect())
     {
         execute_action(
-            runner.delete_symlink(&source, &target),
+            runner.delete_symlink(source, target),
             || resulting_cache.symlinks.remove(source),
             || format!("delete symlink {:?} -> {:?}", source, target),
             &mut suggest_force,
@@ -298,7 +298,7 @@ fn run_deploy<A: ActionRunner>(
         existing_templates.difference(&desired_templates.keys().cloned().collect())
     {
         execute_action(
-            runner.delete_template(&source, &opt.cache_directory.join(&source), &target),
+            runner.delete_template(source, &opt.cache_directory.join(&source), target),
             || resulting_cache.templates.remove(source),
             || format!("delete template {:?} -> {:?}", source, target),
             &mut suggest_force,
@@ -316,7 +316,7 @@ fn run_deploy<A: ActionRunner>(
             .get(&(source.into(), target_path.into()))
             .unwrap();
         execute_action(
-            runner.create_symlink(&source, &target),
+            runner.create_symlink(source, target),
             || {
                 resulting_cache
                     .symlinks
@@ -338,7 +338,7 @@ fn run_deploy<A: ActionRunner>(
             .get(&(source.into(), target_path.into()))
             .unwrap();
         execute_action(
-            runner.create_template(&source, &opt.cache_directory.join(&source), &target),
+            runner.create_template(source, &opt.cache_directory.join(&source), target),
             || {
                 resulting_cache
                     .templates
@@ -357,7 +357,7 @@ fn run_deploy<A: ActionRunner>(
             .get(&(source.into(), target_path.into()))
             .unwrap();
         execute_action(
-            runner.update_symlink(&source, &target),
+            runner.update_symlink(source, target),
             || (),
             || format!("update symlink {:?} -> {:?}", source, target_path),
             &mut suggest_force,
@@ -372,7 +372,7 @@ fn run_deploy<A: ActionRunner>(
             .get(&(source.into(), target_path.into()))
             .unwrap();
         execute_action(
-            runner.update_template(&source, &opt.cache_directory.join(&source), &target),
+            runner.update_template(source, &opt.cache_directory.join(&source), target),
             || (),
             || format!("update template {:?} -> {:?}", source, target_path),
             &mut suggest_force,
